[MLBEDSW-4254] Improve weight information in summary

Improved weight information showed in summary if --verbose-weights
option is used.

Signed-off-by: Fredrik Svedberg <fredrik.svedberg@arm.com>
Change-Id: Iac142f2a813bf1c05aa9da3f8a384466e2914d06
diff --git a/ethosu/vela/api.py b/ethosu/vela/api.py
index f972133..e91c0bd 100644
--- a/ethosu/vela/api.py
+++ b/ethosu/vela/api.py
@@ -416,15 +416,16 @@
     :param ofm_block_depth: the depth of blocks for processing
     :param is_depthwise: a boolean indicating these weights are used for a depthwise traversal
     :param block_traversal: indicates how these weights are traversed on sub-kernel basis
     :return: a bytearray of compressed weights
     """
     from .architecture_features import Accelerator
     from . import weight_compressor
 
     acc = Accelerator.from_npu_accelerator(accelerator)
-    return weight_compressor.encode_weights(
+    encoded_weights, _ = weight_compressor.encode_weights(
         acc, weights_volume, dilation_xy, ifm_bitdepth, ofm_block_depth, is_depthwise, block_traversal
     )
+    return encoded_weights
 
 
 def npu_encode_bias(bias: numpy.int64, scale: int, shift: int):
@@ -416,15 +416,16 @@
     :param is_depthwise: a boolean indicating these weights are used for a depthwise traversal
     :param block_traversal: indicates how these weights are traversed on sub-kernel basis
-    :return: a bytearray of compressed weights
+    :return: a bytearray of encoded weights
     """
     from .architecture_features import Accelerator